# Generated by roxygen2: do not edit by hand

export(wta_get_player_basics)
export(wta_get_player_matches)
export(wta_get_player_overview)
export(wta_get_rankings)
export(wta_player_url)
importFrom(chromote,ChromoteSession)
importFrom(purrr,list_rbind)
importFrom(purrr,map)
importFrom(rvest,html_attr)
importFrom(rvest,html_node)
importFrom(rvest,html_nodes)
importFrom(rvest,html_text)
importFrom(stringr,str_extract)
importFrom(stringr,str_squish)
importFrom(tibble,tibble)
importFrom(xml2,read_html)
